# print_materials.py
# $Rev$
# Copyright (c) 2015 Able Systems Limited. All rights reserved.
'''This simple code example is provided as-is, and is for demonstration
purposes only. Able Systems takes no responsibility for any system
implementations based on this code.

This script prints the required materials for the fourth Pipsta
Circuits project.

The code is based on image_print.py 



Copyright (c) 2015, Able Systems Ltd. All rights reserved.
'''

import argparse
import logging
import platform
import os
import sys
import image_print

LOGGER = logging.getLogger('print_materials.py')

def setup_logging():
    '''Sets up logging for the application.'''
    LOGGER.setLevel(logging.INFO)

    file_handler = logging.FileHandler('mylog.txt')
    file_handler.setLevel(logging.DEBUG)
    file_handler.setFormatter(logging.Formatter(fmt='%(asctime)s %(message)s',
                                                datefmt='%d/%m/%Y %H:%M:%S'))

    stream_handler = logging.StreamHandler()
    stream_handler.setLevel(logging.INFO)

    LOGGER.addHandler(file_handler)
    LOGGER.addHandler(stream_handler)


def parse_arguments():
    '''Parse the filename argument passed to the script. If no
    argument is supplied, a default filename is provided.
    '''
    default_file = "image.png"
    parser = argparse.ArgumentParser()
    parser.add_argument('filename', help='the image file to print',
                        nargs='?', default=default_file)
    return parser.parse_args()



def main():        
    '''This is the main loop where arguments are parsed, connections
     are established, images are processed and the result is
    printed out.
    '''
    args = parse_arguments()
    # This script is written using the PIL which requires Python 2
    if sys.version_info[0] != 2:
        sys.exit('This application requires python 2.')

    if platform.system() != 'Linux':
        sys.exit('This script has only been written for Linux')
    
    setup_logging()

    # Print out the required images (circuit and 'presentation' layers)
    try:
        image_print.send_to_printer(args.filename, "1")
        image_print.send_to_printer("snip.png", "1")
               
    finally:
        # Stop the LED from flashing
        pass
        
if __name__ == '__main__':
    main()
